Package: agricolaeplotr
Type: Package
Title: Visualization of Design of Experiments from the 'agricolae'
        Package
Version: 1.0.0
Authors@R: 
    person(family="Harbers", given="Jens", email="jensharbers@gmail.com", role=c("aut","cre"),
           comment = c(ORCID = "0000-0001-6634-623X"))
Maintainer: Jens Harbers <jensharbers@gmail.com>
Description: Visualization of Design of Experiments from the 'agricolae' package with 'ggplot2' framework
    The user provides an experiment design from the 'agricolae' package, calls the corresponding function and will receive a 
    visualization with 'ggplot2' based functions that are specific for each design. As there are many different designs, each design is tested on its type.
    The output can be modified with standard 'ggplot2' commands or with other packages with 'ggplot2' function extensions.
License: GPL (>= 3)
Encoding: UTF-8
Imports: ggplot2, agricolae, raster, sp (>= 2.0.0), methods, FielDHub,
        utils, tibble, sf, dplyr, tidyr, stringr, stplanr, ggspatial
Language: en-US
Suggests: testthat (>= 3.0.0), knitr, rmarkdown, leaflet
Config/testthat/edition: 3
BugReports: https://github.com/jensharbers/agricolaeplotr/issues
URL: https://github.com/jensharbers/agricolaeplotr
Depends: R (>= 4.0)
VignetteBuilder: knitr
Note: 'None'
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-10 20:15:48 UTC; JensH
Author: Jens Harbers [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6634-623X>)
Repository: CRAN
Date/Publication: 2026-05-11 05:00:02 UTC
Built: R 4.6.0; ; 2026-05-11 05:45:50 UTC; unix
