# Generated by roxygen2: do not edit by hand

export(DOE_obj)
export(citations)
export(full_control_positions)
export(make_polygons)
export(plot_alpha)
export(plot_bib)
export(plot_cyclic)
export(plot_dau)
export(plot_design.factorial_crd)
export(plot_design.factorial_lsd)
export(plot_design.factorial_rcbd)
export(plot_design_crd)
export(plot_fieldhub)
export(plot_graeco)
export(plot_latin_square)
export(plot_lattice_simple)
export(plot_lattice_triple)
export(plot_longest_diagonal)
export(plot_rcbd)
export(plot_split_crd)
export(plot_split_lsd)
export(plot_split_rcbd)
export(plot_strip)
export(plot_youden)
export(protective_layers)
export(sample_locations)
export(serpentine)
export(summary)
export(test_input_extend)
export(test_input_ncols)
export(test_input_nrows)
export(test_input_reverse)
export(test_input_shift)
export(test_name_in_column)
export(test_names_design)
export(test_string)
export(theme_gi)
export(theme_poster)
export(theme_pres)
export(to_table)
import(FielDHub)
import(agricolae)
import(ggplot2)
import(sf)
importFrom(dplyr,`%>%`)
importFrom(dplyr,filter)
importFrom(ggplot2,geom_sf)
importFrom(ggplot2,ggplot)
importFrom(ggspatial,annotation_north_arrow)
importFrom(ggspatial,annotation_scale)
importFrom(raster,crs)
importFrom(raster,extent)
importFrom(sf,st_sample)
importFrom(stats,dist)
importFrom(stplanr,line_segment)
importFrom(stringr,str_wrap)
importFrom(tibble,as_tibble)
importFrom(tibble,rownames_to_column)
importFrom(tidyr,gather)
